@@ -4,7 +4,7 @@ use warnings;
 package HTTP::Tiny::UA;
 # ABSTRACT: Higher-level UA features for HTTP::Tiny
 
-our $VERSION = '0.003';
+our $VERSION = '0.004'; # from HTTP-Tiny-UA-0.004.tar.gz
 
 use superclass 'HTTP::Tiny' => 0.036;
 
@@ -85,7 +85,7 @@ HTTP::Tiny::UA - Higher-level UA features for HTTP::Tiny
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -273,12 +273,22 @@ L<https://github.com/dagolden/HTTP-Tiny-UA>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Graham Ollis
+=for stopwords Felipe Gasper Graham Ollis
+
+=over 4
+
+=item *
+
+Felipe Gasper <felipe@felipegasper.com>
+
+=item *
 
 Graham Ollis <perl@wdlabs.com>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
