@@ -4,9 +4,12 @@ use warnings;
 package HTTP::Tiny::UA::Response;
 # ABSTRACT: Wrap HTTP::Tiny response as objects with accessors
 
-our $VERSION = '0.003';
+our $VERSION = '0.004'; # from HTTP-Tiny-UA-0.004.tar.gz
 
-use Class::Tiny qw( success url status reason content headers protocol );
+# Declare custom accessor before Class::Tiny loads
+use subs 'headers';
+
+use Class::Tiny qw( success url status reason content protocol headers );
 
 #pod =attr success
 #pod
@@ -32,9 +35,34 @@ use Class::Tiny qw( success url status reason content headers protocol );
 #pod
 #pod =cut
 
+# Don't return the original hash reference because the caller could
+# alter that referred-to hash, which in turn would alter this object's
+# internals, which we almost certainly do not want!
+sub headers {
+    my ($self) = @_;
+
+    my $headers = $self->{headers};
+    my %copy;
+
+    while ( my ( $k, $v ) = each %$headers ) {
+        $copy{$k} = ref($v) eq 'ARRAY' ? [@$v] : $v;
+    }
+
+    return \%copy;
+}
+
 sub header {
     my ( $self, $field ) = @_;
-    return $self->headers->{ lc $field };
+
+    # NB: lc() can potentially use non-English (e.g., Turkish)
+    # lowercasing logic, which we very likely do not want here.
+    $field =~ tr/A-Z/a-z/;
+
+    # We don't return the original array reference for the same reason
+    # why headers() doesn't return the original hash reference.
+    my $hdr = $self->{headers}{$field};
+
+    return ref($hdr) eq 'ARRAY' ? [@$hdr] : $hdr;
 }
 
 1;
@@ -54,7 +82,7 @@ HTTP::Tiny::UA::Response - Wrap HTTP::Tiny response as objects with accessors
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
